@@ -584,15 +584,17 @@ cr_marg_probs <- function (eta, direction = c("forward", "backward")) {
     direction <- match.arg(direction)
     ncoefs <- ncol(eta)
     if (direction == "forward") {
-        cumsum_1_minus_p <- t(apply(plogis(eta[, -ncoefs], log.p = TRUE, 
-                                           lower.tail = FALSE), 1, cumsum))
+        cumsum_1_minus_p <- apply(plogis(eta[, -ncoefs, drop = FALSE], log.p = TRUE, 
+                                           lower.tail = FALSE), 1L, cumsum)
+        if (is.matrix(cumsum_1_minus_p)) cumsum_1_minus_p <- t(cumsum_1_minus_p)
         probs <- exp(plogis(eta, log.p = TRUE) + cbind(0, cumsum_1_minus_p))
         cbind(probs, 1 - rowSums(probs))
     } else {
-        cumsum_1_minus_p <- t(apply(plogis(eta[, seq(ncoefs, 2)], log.p = TRUE, 
-                                           lower.tail = FALSE), 1, cumsum))
+        cumsum_1_minus_p <- apply(plogis(eta[, seq(ncoefs, 2), drop = FALSE], log.p = TRUE, 
+                                           lower.tail = FALSE), 1L, cumsum)
+        cumsum_1_minus_p <- if (is.matrix(cumsum_1_minus_p)) t(cumsum_1_minus_p) else as.matrix(cumsum_1_minus_p)
         probs <- exp(plogis(eta, log.p = TRUE) + 
                          cbind(cumsum_1_minus_p[, seq(ncoefs - 1, 1)], 0))
         cbind(1 - rowSums(probs), probs)
     }
-}
\ No newline at end of file
+}
